@@ -16,6 +16,7 @@ from sklearn.neighbors import KNeighborsClassifier
 import requests
 
 
+
 def linear_regression(input_i, output_o, return_val):
     """
     linear regression, give two array and a value to predict it's output.
@@ -77,6 +78,7 @@ class Predict:
         Returns: 
             int: predicted population
         """
+
         return linear_regression([1500, 1650, 1750, 1804, 1850, 1900, 1927, 1950, 1955, 1960, 1965, 1970, 1975, 1980, 1985, 1990, 1995, 1999, 2006, 2009, 2011, 2020], [450000000, 500000000, 700000000, 1000000000, 1200000000, 1600000000, 2000000000, 2550000000, 2800000000, 3000000000, 3300000000, 3700000000, 4000000000, 4500000000, 4850000000, 5300000000, 5700000000, 6000000000, 6500000000, 6800000000, 7000000000, 7800000000], self.year)
 
     def climate_change(self):
@@ -251,3 +253,19 @@ def Predict_Epidemic(year):
         [population, climate_change, democracy_index, poverty, global_health, flight], year)
     return correct, prediction, epi
 
+def example():
+
+    year = int(input('Which year do you want to predict?'))
+    correct, prediction, epi = Predict_Epidemic(year)
+
+    if epi != None and epi != 'no':
+        print(colored(f'In {year}, {epi} happened.', 'red'))
+
+    elif epi == 'no':
+        print(colored(f'In {year}, there\'s no major epidemic happened', 'green'))
+
+    elif epi == None and prediction == 0:
+        print(colored(f'In {year}, there\'s {correct * 100}% that an epidemic may NOT happen', 'green'))
+
+    elif epi == None and prediction == 1:
+        print(colored(f'In {year}, there\'s {correct * 100}% that an epidemic may happen', 'red'))
\ No newline at end of file
